package com.ruoyi.system.utils;

import com.ruoyi.common.core.utils.DateUtils;
import java.io.ByteArrayInputStream;
import java.net.URL;
import java.security.cert.Certificate;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import java.util.Date;
import javax.net.ssl.HttpsURLConnection;

public class SSLExpirationChecker {
   public static String getCertificateExStr(String certificateStr) {
      try {
         Date expirationDate = getCertificateExDate(certificateStr);
         return expirationDate == null ? null : DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, expirationDate);
      } catch (Exception var2) {
         return "";
      }
   }

   public static Date getCertificateExDate(String certificateStr) {
      try {
         byte[] certBytes = certificateStr.getBytes();
         CertificateFactory cf = CertificateFactory.getInstance("X.509");
         ByteArrayInputStream bis = new ByteArrayInputStream(certBytes);
         X509Certificate cert = (X509Certificate)cf.generateCertificate(bis);
         return cert.getNotAfter();
      } catch (Exception var5) {
         return null;
      }
   }

   public static String getSSLCertificateExpirationDate(String urlString) {
      try {
         URL url = new URL("https://" + urlString);
         HttpsURLConnection connection = (HttpsURLConnection)url.openConnection();
         connection.setConnectTimeout(5000);
         connection.setReadTimeout(5000);
         connection.connect();
         Certificate[] certs = connection.getServerCertificates();
         if (certs.length > 0) {
            X509Certificate cert = (X509Certificate)certs[0];
            Date expirationDate = cert.getNotAfter();
            return DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, expirationDate);
         }
      } catch (Exception var6) {
      }

      return "";
   }

   public static void main(String[] args) {
      String urlString = "-----BEGIN CERTIFICATE-----\nMIIE6TCCA9GgAwIBAgISA7EuIxJ44aHCKlAQSlz+SUrJMA0GCSqGSIb3DQEBCwUA\nMDMxCzAJBgNVBAYTAlVTMRYwFAYDVQQKEw1MZXQncyBFbmNyeXB0MQwwCgYDVQQD\nEwNSMTAwHhcNMjQwODA4MDA1MjUyWhcNMjQxMTA2MDA1MjUxWjAYMRYwFAYDVQQD\nEw1iLnhpbnM2MTEuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nvN0i2ZrcFVl1cNZYGgzQnkGl+OG0OJ1UpYhzeoE/qICewr/QfHUBX9+78fDY1kYt\nqqhHoUc20yPpL60NMOUsh7DHP4BCEoK5eO2ADE5zdPM7W2Ut3CRGChLOgMTHDGBS\n0O3V/Af48+ayiLbx0LrKg2W0EYzcfK19Me9K3EcWW2hdSxUjdJ8fIuwmhP/0+tAv\nV2kLzUUOlZKp02YgLpntk366Rb0hqtNlFmJgVstG3Mu8pRsOCdjaIlQJ1eXocyoo\nCSyXFGRdK7Vr3HbFUMIUj4ZBwRQ+FqpaotumBsaqr4dO82CyUCDkAgubn2UP/6IR\nSfUmCXKViE/fG1AdH/zyiwIDAQABo4ICEDCCAgwwDgYDVR0PAQH/BAQDAgWgMB0G\nA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAMBgNVHRMBAf8EAjAAMB0GA1Ud\nDgQWBBQuKi+KmyoVk9CXtjBOmo5C2knW/DAfBgNVHSMEGDAWgBS7vMNHpeS8qcbD\npHIMEI2iNeHI6DBXBggrBgEFBQcBAQRLMEkwIgYIKwYBBQUHMAGGFmh0dHA6Ly9y\nMTAuby5sZW5jci5vcmcwIwYIKwYBBQUHMAKGF2h0dHA6Ly9yMTAuaS5sZW5jci5v\ncmcvMBgGA1UdEQQRMA+CDWIueGluczYxMS5jb20wEwYDVR0gBAwwCjAIBgZngQwB\nAgEwggEDBgorBgEEAdZ5AgQCBIH0BIHxAO8AdQBIsONr2qZHNA/lagL6nTDrHFIB\ny1bdLIHZu7+rOdiEcwAAAZEvrvybAAAEAwBGMEQCICuqxbHMYyUw4+PBRdqt1IqQ\noLbEcvVvWGQ5ZlmxdRrAAiAZMEaZCseFR4/H7yrwQSZ84UN/5F3R2AhF+Q08bXSC\nPQB2AHb/iD8KtvuVUcJhzPWHujS0pM27KdxoQgqf5mdMWjp0AAABkS+u/OsAAAQD\nAEcwRQIhAPKRlFdWWFtFqZO2+thgpcqOo5L/US02o83/rrkugw6AAiA40Ut9TrrN\ndpwRy+WZZUAIYOrm+T1nbJsQPv4uQ8tJZDANBgkqhkiG9w0BAQsFAAOCAQEAse/B\nVhDgj8WHldmvUDJugUAQHrYaSIP5eUMYzTw+fnIe+DT4GDiSIKLWOYZGw4mVnqfz\nf0Yn+3M+1cDhXhblf2y4/0aR6g3IIDgx4ZgNLcPDlzR/I6YxFIf06acyw37z6N4b\nWtH+OAOwhHTZ5WFR3wyjZV9POQBYl9QUWqcQpqGCRfsEVezfOhQEIA/21BfBU0Ry\nMsJP9r1A7ghGlrH5npF57YxyjlDPQZF6DOlzQoOGWuIj+cRrbwrgEq+a0gNVUk1h\n6CBfGBx8dGoRjVaPyPGVX3A26je5L7TFJa41deQBDICZsN5IgW4wNLZIK3kiIIP6\ntYemSyYKke73HJQm4A==\n-----END CERTIFICATE-----\n-----BEGIN CERTIFICATE-----\nMIIFBTCCAu2gAwIBAgIQS6hSk/eaL6JzBkuoBI110DANBgkqhkiG9w0BAQsFADBP\nMQswCQYDVQQGEwJVUzEpMCcGA1UEChMgSW50ZXJuZXQgU2VjdXJpdHkgUmVzZWFy\nY2ggR3JvdXAxFTATBgNVBAMTDElTUkcgUm9vdCBYMTAeFw0yNDAzMTMwMDAwMDBa\nFw0yNzAzMTIyMzU5NTlaMDMxCzAJBgNVBAYTAlVTMRYwFAYDVQQKEw1MZXQncyBF\nbmNyeXB0MQwwCgYDVQQDEwNSMTAwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQDPV+XmxFQS7bRH/sknWHZGUCiMHT6I3wWd1bUYKb3dtVq/+vbOo76vACFL\nYlpaPAEvxVgD9on/jhFD68G14BQHlo9vH9fnuoE5CXVlt8KvGFs3Jijno/QHK20a\n/6tYvJWuQP/py1fEtVt/eA0YYbwX51TGu0mRzW4Y0YCF7qZlNrx06rxQTOr8IfM4\nFpOUurDTazgGzRYSespSdcitdrLCnF2YRVxvYXvGLe48E1KGAdlX5jgc3421H5KR\nmudKHMxFqHJV8LDmowfs/acbZp4/SItxhHFYyTr6717yW0QrPHTnj7JHwQdqzZq3\nDZb3EoEmUVQK7GH29/Xi8orIlQ2NAgMBAAGjgfgwgfUwDgYDVR0PAQH/BAQDAgGG\nMB0GA1UdJQQWMBQGCCsGAQUFBwMCBggrBgEFBQcDATASBgNVHRMBAf8ECDAGAQH/\nAgEAMB0GA1UdDgQWBBS7vMNHpeS8qcbDpHIMEI2iNeHI6DAfBgNVHSMEGDAWgBR5\ntFnme7bl5AFzgAiIyBpY9umbbjAyBggrBgEFBQcBAQQmMCQwIgYIKwYBBQUHMAKG\nFmh0dHA6Ly94MS5pLmxlbmNyLm9yZy8wEwYDVR0gBAwwCjAIBgZngQwBAgEwJwYD\nVR0fBCAwHjAcoBqgGIYWaHR0cDovL3gxLmMubGVuY3Iub3JnLzANBgkqhkiG9w0B\nAQsFAAOCAgEAkrHnQTfreZ2B5s3iJeE6IOmQRJWjgVzPw139vaBw1bGWKCIL0vIo\nzwzn1OZDjCQiHcFCktEJr59L9MhwTyAWsVrdAfYf+B9haxQnsHKNY67u4s5Lzzfd\nu6PUzeetUK29v+PsPmI2cJkxp+iN3epi4hKu9ZzUPSwMqtCceb7qPVxEbpYxY1p9\n1n5PJKBLBX9eb9LU6l8zSxPWV7bK3lG4XaMJgnT9x3ies7msFtpKK5bDtotij/l0\nGaKeA97pb5uwD9KgWvaFXMIEt8jVTjLEvwRdvCn294GPDF08U8lAkIv7tghluaQh\n1QnlE4SEN4LOECj8dsIGJXpGUk3aU3KkJz9icKy+aUgA+2cP21uh6NcDIS3XyfaZ\nQjmDQ993ChII8SXWupQZVBiIpcWO4RqZk3lr7Bz5MUCwzDIA359e57SSq5CCkY0N\n4B6Vulk7LktfwrdGNVI5BsC9qqxSwSKgRJeZ9wygIaehbHFHFhcBaMDKpiZlBHyz\nrsnnlFXCb5s8HKn5LsUgGvB24L7sGNZP2CX7dhHov+YhD+jozLW2p9W4959Bz2Ei\nRmqDtmiXLnzqTpXbI+suyCsohKRg6Un0RC47+cpiVwHiXZAW+cn8eiNIjqbVgXLx\nKPpdzvvtTnOPlC7SQZSYmdunr3Bf9b77AiC/ZidstK36dRILKz7OA54=\n-----END CERTIFICATE-----";
      String expirationDate = getCertificateExStr(urlString);
      if (expirationDate != null) {
         System.out.println("证书过期时间: " + expirationDate);
      } else {
         System.out.println("无法获取证书过期时间");
      }

   }
}
